Structs

Constants

The maximum number of bytes we expect in a varint. We use this to check if we’re encountering a decoding error for a varint.

Functions

Attempt to decode a message of type M from the given source buffer.

Encode the given message with a length prefix.